@@ -1,12 +1,12 @@
 package Getopt::Long::Subcommand;
 
-our $DATE = '2016-12-02'; # DATE
-our $VERSION = '0.06'; # VERSION
+our $DATE = '2017-01-03'; # DATE
+our $VERSION = '0.07'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
-use Log::Any::IfLOG '$log';
+#use Log::Any::IfLOG '$log';
 
 require Exporter;
 our @ISA = qw(Exporter);
@@ -49,17 +49,17 @@ sub _gl_getoptions {
     require Getopt::Long;
 
     my ($ospec, $pass_through) = @_;
-    $log->tracef('[comp][glsubc] Performing Getopt::Long::GetOptions');
+    #$log->tracef('[comp][glsubc] Performing Getopt::Long::GetOptions');
 
     my $old_conf = Getopt::Long::Configure(
-        'no_ignore_case', 'bundling', 'no_getopt_compat', 'gnu_compat',
+        'no_ignore_case', 'no_getopt_compat', 'gnu_compat', 'bundling',
         ('pass_through') x !!$pass_through,
     );
     local $SIG{__WARN__} = sub {} if $pass_through;
-    $log->tracef('[comp][glsubc] @ARGV before Getopt::Long::GetOptions: %s', \@ARGV);
-    $log->tracef('[comp][glsubc] spec for Getopt::Long::GetOptions: %s', $ospec);
+    #$log->tracef('[comp][glsubc] @ARGV before Getopt::Long::GetOptions: %s', \@ARGV);
+    #$log->tracef('[comp][glsubc] spec for Getopt::Long::GetOptions: %s', $ospec);
     my $gl_res = Getopt::Long::GetOptions(%$ospec);
-    $log->tracef('[comp][glsubc] @ARGV after  Getopt::Long::GetOptions: %s', \@ARGV);
+    #$log->tracef('[comp][glsubc] @ARGV after  Getopt::Long::GetOptions: %s', \@ARGV);
     Getopt::Long::Configure($old_conf);
     $gl_res;
 }
@@ -75,11 +75,10 @@ sub _GetOptions {
 
     # check command spec
     {
-        use experimental 'smartmatch';
-        $log->tracef("[comp][glsubc] Checking cmdspec keys: %s", [keys %$cmdspec]);
-        for (keys %$cmdspec) {
-            $_ ~~ @known_cmdspec_keys
-                or die "Unknown command specification key '$_'" .
+        #$log->tracef("[comp][glsubc] Checking cmdspec keys: %s", [keys %$cmdspec]);
+        for my $k (keys %$cmdspec) {
+            (grep { $_ eq $k } @known_cmdspec_keys)
+                or die "Unknown command specification key '$k'" .
                     ($stash->{path} ? " (under $stash->{path})" : "") . "\n";
         }
     }
@@ -146,7 +145,7 @@ sub _GetOptions {
     }
     $res->{success} //= 1;
 
-    $log->tracef('[comp][glsubc] Final @ARGV: %s', \@ARGV) unless $stash->{path};
+    #$log->tracef('[comp][glsubc] Final @ARGV: %s', \@ARGV) unless $stash->{path};
     #$log->tracef('[comp][glsubc] TMP: stash=%s', $stash);
     #$log->tracef('[comp][glsubc] TMP: res=%s', $res);
     $res;
@@ -251,7 +250,7 @@ Getopt::Long::Subcommand - Process command-line options, with subcommands and co
 
 =head1 VERSION
 
-This document describes version 0.06 of Getopt::Long::Subcommand (from Perl distribution Getopt-Long-Subcommand), released on 2016-12-02.
+This document describes version 0.07 of Getopt::Long::Subcommand (from Perl distribution Getopt-Long-Subcommand), released on 2017-01-03.
 
 =head1 SYNOPSIS
 
@@ -342,8 +341,6 @@ To run your script:
 
 =head1 DESCRIPTION
 
-B<STATUS: EARLY RELEASE, EXPERIMENTAL.>
-
 This module extends L<Getopt::Long> with subcommands and tab completion ability.
 
 How parsing works: First we call C<Getopt::Long::GetOptions> with the top-level
@@ -465,7 +462,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
